@@ -92,7 +92,9 @@ class mainwindow:
             self.calculator_subbox.destroy()
             # Seems gconf does not propagate fast enough...
             calculator.instance.mode = self.gc.get_string('/apps/maecalories/settings/calculator_mode')
-        self.calculator_subbox = calculator.instance.render_calculator()
+        #self.calculator_subbox = calculator.instance.render_calculator()
+        calc = calculator.calculator()
+        self.calculator_subbox = calc.render_calculator()
         self.calculator_box.pack_start(self.calculator_subbox)
         self.calculator_box.show_all()
 
