@@ -71,9 +71,9 @@ class wrapper:
                 # Bug http://trac.midgard-project.org/ticket/1409
                 if window:
                     import hildon, gtk
-                    note = hildon.Note('information', window, "Hit Midgard bug #1409, please restart application")
+                    note = hildon.Note('information', window, "Hit Midgard bug #1409, please restart application, if problem persists delete ~/.midgard2/data/maecalories.db and reinstall")
                     gtk.Dialog.run(note)
-                raise Exception("Hit Midgard bug #1409, restart application")
+                raise Exception("Hit Midgard bug #1409, restart application, if problem persists delete ~/.midgard2/data/maecalories.db and reinstall")
         elif count > 1:
             # Display selector and save choice
             raise Exception('Multiple user handling not implemented')
@@ -156,10 +156,10 @@ class wrapper:
         return True
 
     def get_week(self, now=None):
-        """Resolve start and end datetimes for current week"""
+        """Resolve start and end datetimes for current week (local time)"""
         import datetime
         if now == None:
-            now = utcstamp()
+            now = datetime.datetime.now()
         sow = self.gc.get_int('/apps/maecalories/settings/week_starts')
         if sow == None:
             self.gc.set_int('/apps/maecalories/settings/week_starts', 0)
@@ -180,10 +180,10 @@ class wrapper:
         return (weekstart, weekend)
 
     def get_day(self, now=None):
-        """Resolve start and end timestamps for today"""
+        """Resolve start and end timestamps for today (local time)"""
         import datetime
         if now == None:
-            now = utcstamp()
+            now = datetime.datetime.now()
         daystart = now.replace(hour=0, minute=0, second=1)
         dayend = now.replace(hour=23, minute=59, second=59)
         return (daystart, dayend)
@@ -192,6 +192,7 @@ class wrapper:
         # Init datetimes we need
         week = self.get_week()
         day = self.get_day()
+        qb_offset = utcoffset()
 
         # Init related config variables
         ppd = self.gc.get_float('/apps/maecalories/settings/points_per_day')
@@ -211,8 +212,8 @@ class wrapper:
 
         # Get weeks points log entries
         qb_week = midgard.query_builder('org_maemo_garage_maecalories_pointslog')
-        qb_week.add_constraint('time', '>=', dt_to_constraint(week[0]))
-        qb_week.add_constraint('time', '<=', dt_to_constraint(week[1]))
+        qb_week.add_constraint('time', '>=', dt_to_constraint(week[0], qb_offset))
+        qb_week.add_constraint('time', '<=', dt_to_constraint(week[1], qb_offset))
         qb_week.add_order('time', 'ASC')
         items = qb_week.execute()
         for item in items:
@@ -243,7 +244,7 @@ class wrapper:
 
         qb_wt = midgard.query_builder('org_maemo_garage_maecalories_weightlog')
         # Just in case some brainiac manages to post-date a weight log entry
-        qb_wt.add_constraint('time', '<=', dt_to_constraint(day[1]))
+        qb_wt.add_constraint('time', '<=', dt_to_constraint(day[1], qb_offset))
         qb_wt.add_order('time', 'DESC')
         qb_wt.set_limit(1)
         wt_count = qb_wt.count()
@@ -266,12 +267,18 @@ class wrapper:
             return False
         return True
 
+def utcoffset():
+    import datetime
+    return datetime.datetime.now() - datetime.datetime.utcnow()
+
 def utcstamp():
     """Helper fuction to return current UTC timestamp as datime"""
     import datetime
     return datetime.datetime.utcnow()
 
-def dt_to_constraint(dt):
+def dt_to_constraint(dt, offset=None):
+    if (offset):
+        dt = dt - offset
     return dt.strftime('%Y-%m-%d %H:%M:%S')
 
 # Use this instantiated wrapper object to access the base storage
